==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/is.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Meðaltalsálag",
    "Last minute" : "Á síðustu mínútu",
    "Memory info not available" : "Upplýsingar um minni eru ekki tiltækar",
    "Total" : "Alls",
    "Current usage" : "Núverandi notkun",
    "Users" : "Notendur",
    "Groups" : "Hópar",
    "Links" : "Tenglar",
    "Federated sent" : "Skýjasamband sent",
    "Federated received" : "Skýjasamband móttekið",
    "Last 24 hours" : "Síðustu 24 klst",
    "Last 1 hour" : "Síðustu klst",
    "Last 5 mins" : "Síðustu 5 mín",
    "Copy" : "Afrita",
    "Copied!" : "Afritað!",
    "Not supported!" : "Ekki stutt!",
    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
    "Monitoring" : "Vöktun",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Gefur nytsamlegar upplýsingar um vefþjón, svo sem álag á örgjörva, diskanotkun, fjölda notenda, o.s.frv.",
    "CPU load" : "Örgjörvaálag",
    "Memory usage" : "Minnisnotkun",
    "Active users" : "Virkir notendur",
    "Shares" : "Sameignir",
    "Storage" : "Gagnageymslur",
    "Users:" : "Notendur:",
    "Files:" : "Skrár:",
    "Storages:" : "Gagnageymslur",
    "Free Space:" : "Laust diskapláss:",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Útgáfa:",
    "Apps installed:" : "Uppsett forrit:",
    "Apps updates available:" : "Tiltækar forritsuppfærslur:",
    "PHP" : "PHP",
    "Memory Limit:" : "Minnistakmörk:",
    "Max Execution Time:" : "Hámarks keyrslutími:",
    "Upload max size:" : "Hámarksstærð innsendingar:",
    "Database" : "Gagnagrunnur",
    "Type:" : "Tegund:",
    "Size:" : "Stærð:",
    "External monitoring tool" : "Utanaðkomandi vöktunartól",
    "You can connect an external monitoring tool by using this end point:" : "Þú getur tengt utanaðkomandi vöktunartól með því að nota þennan endapunkt: ",
    "You can connect an external monitoring tool by using this end point: " : "Þú getur tengt utanaðkomandi vöktunartól með því að nota þennan endapunkt: "
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-15.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/is.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Örgjörvaupplýsingar ekki tiltækar",
    "Load average" : "Meðaltalsálag",
    "Last minute" : "Á síðustu mínútu",
    "Memory info not available" : "Upplýsingar um minni eru ekki tiltækar",
    "Total" : "Alls",
    "Current usage" : "Núverandi notkun",
    "Users" : "Notendur",
    "Groups" : "Hópar",
    "Links" : "Tenglar",
    "Federated sent" : "Skýjasamband sent",
    "Federated received" : "Skýjasamband móttekið",
    "Last 24 hours" : "Síðustu 24 klst",
    "Last 1 hour" : "Síðustu klst",
    "Last 5 mins" : "Síðustu 5 mín",
    "Copy" : "Afrita",
    "Copied!" : "Afritað!",
    "Not supported!" : "Ekki stutt!",
    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
    "Monitoring" : "Vöktun",
    "Monitoring app with useful server information" : "Vöktunarforrit sem nær í ýmsar notadrjúgar upplýsingar um þjón",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Gefur nytsamlegar upplýsingar um vefþjón, svo sem álag á örgjörva, diskanotkun, fjölda notenda, o.s.frv.",
    "CPU load" : "Örgjörvaálag",
    "Memory usage" : "Minnisnotkun",
    "Active users" : "Virkir notendur",
    "Shares" : "Sameignir",
    "Storage" : "Gagnageymslur",
    "Users:" : "Notendur:",
    "Files:" : "Skrár:",
    "Storages:" : "Gagnageymslur",
    "Free Space:" : "Laust diskapláss:",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Útgáfa:",
    "Apps installed:" : "Uppsett forrit:",
    "Apps updates available:" : "Tiltækar forritsuppfærslur:",
    "PHP" : "PHP",
    "Memory Limit:" : "Minnistakmörk:",
    "Max Execution Time:" : "Hámarks keyrslutími:",
    "Upload max size:" : "Hámarksstærð innsendingar:",
    "Database" : "Gagnagrunnur",
    "Type:" : "Tegund:",
    "Size:" : "Stærð:",
    "External monitoring tool" : "Utanaðkomandi vöktunartól",
    "You can connect an external monitoring tool by using this end point:" : "Þú getur tengt utanaðkomandi vöktunartól með því að nota þennan endapunkt: ",
    "Did you know?" : "Vissirðu?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Að með því að bæta \"?format=json\" við enda URL-slóðar, muntu fá niðurstöðurnar á JSON-sniði!",
    "You can connect an external monitoring tool by using this end point: " : "Þú getur tengt utanaðkomandi vöktunartól með því að nota þennan endapunkt: "
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
